@@ -3,8 +3,8 @@
 
 #include <glib-object.h>
 
-/* enumerations from "/usr/src/ports/engrampa/engrampa-1.8.1-1.x86_64/src/engrampa-1.8.1/src/typedefs.h" */
-#include "/usr/src/ports/engrampa/engrampa-1.8.1-1.x86_64/src/engrampa-1.8.1/src/typedefs.h"
+/* enumerations from "/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/typedefs.h" */
+#include "/usr/src/ports/engrampa/engrampa-1.10.1-1.x86_64/src/engrampa-1.10.1/src/typedefs.h"
 GType
 fr_compression_get_type (void)
 {
@@ -21,6 +21,21 @@ fr_compression_get_type (void)
   }
   return etype;
 }
+GType
+fr_overwrite_get_type (void)
+{
+  static GType etype = 0;
+  if (etype == 0) {
+    static const GEnumValue values[] = {
+      { FR_OVERWRITE_YES, "FR_OVERWRITE_YES", "yes" },
+      { FR_OVERWRITE_NO, "FR_OVERWRITE_NO", "no" },
+      { FR_OVERWRITE_ASK, "FR_OVERWRITE_ASK", "ask" },
+      { 0, NULL, NULL }
+    };
+    etype = g_enum_register_static ("FrOverwrite", values);
+  }
+  return etype;
+}
 
 
 
